@@ -57,6 +57,7 @@ conversions.
     c1 = m.c1
 """
 from __future__ import absolute_import
+from numbers import Number
 import numpy as np
 from multipledispatch import dispatch
 from .base import BaseObject, BaseMatrix, BaseMatrix44, BaseQuaternion, BaseVector, NpProxy
@@ -206,6 +207,14 @@ class Matrix44(BaseMatrix44):
 
     ########################
     # Matrices
+    @dispatch(BaseMatrix)
+    def __add__(self, other):
+        return Matrix44(super(Matrix44, self).__add__(other.matrix44))
+
+    @dispatch(BaseMatrix)
+    def __sub__(self, other):
+        return Matrix44(super(Matrix44, self).__sub__(other.matrix44))
+
     @dispatch(BaseMatrix)
     def __mul__(self, other):
         return Matrix44(matrix44.multiply(self, other.matrix44))
@@ -223,6 +232,28 @@ class Matrix44(BaseMatrix44):
     def __mul__(self, other):
         return type(other)(matrix44.apply_to_vector(self, other))
 
+    ########################
+    # Number
+    @dispatch(Number)
+    def __add__(self, other):
+        return Matrix44(super(Matrix44, self).__add__(other))
+
+    @dispatch(Number)
+    def __sub__(self, other):
+        return Matrix44(super(Matrix44, self).__sub__(other))
+
+    @dispatch(Number)
+    def __mul__(self, other):
+        return Matrix44(super(Matrix44, self).__mul__(other))
+
+    @dispatch(Number)
+    def __truediv__(self, other):
+        return Matrix44(super(Matrix44, self).__truediv__(other))
+
+    @dispatch(Number)
+    def __div__(self, other):
+        return Matrix44(super(Matrix44, self).__div__(other))
+
     ########################
     # Methods and Properties
     @property
